[**Opzioni avanzate**](./introduction.md) > **Codice lingua** _(current)_

---

#### Google

Fonte <https://developers.google.com/admin-sdk/directory/v1/languages?hl=zh-cn>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Codice lingua` |
| --- | --- | --- |
| Amarico | Amharic | `am` |
| Arabo | Arabic | `ar` |
| 巴斯克语 | Basque | `eu` |
| Bengalese | Bengali | `bn` |
| Italiano (Italia) | Italiano (Italia) | `it-IT` |
| Portoghese (Brasile) | Portoghese (Brasile) | `pt-BR` |
| Bulgaro | Bulgarian | `bg` |
| Catalano | Catalan | `ca` |
| Cherokee | Cherokee | `chr` |
| Croato | Croatian | `hr` |
| Ceco | Czech | `cs` |
| Danese | Danish | `da` |
| Olandese | Dutch | `nl` |
| 英语（美国） | English (US) | `en` |
| Estone | Estonian | `et` |
| Filippino | Filipino | `fil` |
| Finlandese | Finnish | `fi` |
| Francese | French | `fr` |
| Tedesco | German | `de` |
| Greco | Greek | `el` |
| 古吉拉特语 | Gujarati | `gu` |
| Ebraico | Hebrew | `iw` |
| हिंदी | Hindi | `hi` |
| Ungherese | Hungarian | `hu` |
| Islandese | Icelandic | `is` |
| Bahasa Indonesia | Indonesian | `id` |
| Italiano | Italian | `it` |
| 日本語 | Japanese | `ja` |
| Kannada | Kannada | `kn` |
| 韩语 | Coreano | `ko` |
| Lettone | Latvian | `lv` |
| Lituano | Lithuanian | `lt` |
| Malese | Malay | `ms` |
| മലയാളം | Malayalam | `ml` |
| मराठी | Marathi | `mr` |
| Norvegese | Norwegian | `no` |
| Polacco | Polish | `pl` |
| Portoghese (Portogallo) | Portoghese (Portogallo) | `pt-PT` |
| Rumeno | Romanian | `ro` |
| Russo | Russian | `ru` |
| Serbo | Serbian | `sr` |
| Italiano (Italia) | Italian (Italy) | `it-IT` |
| Slovacco | Slovak | `sk` |
| Sloveno | Slovenian | `sl` |
| Spagnolo | Spanish | `es` |
| 斯瓦希里语 | Swahili | `sw` |
| Svedese | Swedish | `sv` |
| 泰米尔语 | Tamil | `ta` |
| 泰卢固语 | Telugu | `te` |
| 泰语 | Thai | `th` |
| 中文（台湾） | Chinese (Taiwan) | `zh-TW` |
| 土耳其语 | Turkish | `tr` |
| 乌尔都语 | Urdu | `ur` |
| Ucraino | Ukrainian | `uk` |
| Tiếng Việt | Vietnamese | `vi` |
| Gallese | Welsh | `cy` |


#### DeepL
Fonte <https://developers.deepl.com/docs/resources/supported-languages>, organizzato da GPT-4o.

| Etichetta in cinese | Etichetta | `Language Code` | Supporta |
| --- | --- | --- | --- |
| Arabo | Arabic | `AR` | `source`, `target` |
| Bulgaro | Bulgarian | `BG` | `source`, `target` |
| Ceco | Czech | `CS` | `source`, `target` |
| Danese | Danish | `DA` | `source`, `target` |
| Tedesco | German | `DE` | `source`, `target` |
| Greco | Greek | `EL` | `source`, `target` |
| Italiano | Italiano | `IT` | `source`, `target` |
| Italiano (Italia) | Italiano (Italia) | `IT-IT` | `target` |
| Italiano (Italia) | Italiano (Italiano) | `IT-IT` | `target` |
| Spagnolo | Spanish | `ES` | `source`, `target` |
| Estone | Estonian | `ET` | `source`, `target` |
| Finlandese | Finnish | `FI` | `source`, `target` |
| Francese | French | `FR` | `source`, `target` |
| Ungherese | Hungarian | `HU` | `source`, `target` |
| 印度尼西亚语 | Indonesian | `ID` | `source`, `target` |
| Italiano | Italian | `IT` | `source`, `target` |
| 日本語 | Japanese | `JA` | `source`, `target` |
| Coreano | Coreano | `KO` | `source`, `target` |
| Lituano | Lithuanian | `LT` | `source`, `target` |
| Lettone | Lettone | `LV` | `source`, `target` |
| Norvegese Bokmål | Norvegese Bokmål | `NB` | `source`, `target` |
| Olandese | Dutch | `NL` | `source`, `target` |
| Polacco | Polish | `PL` | `source`, `target` |
| Portoghese | Portoghese | `PT` | `source`, `target` |
| Português (Brasil) | Portuguese (Brazilian) | `PT-BR` | `target` |
| Portoghese (europeo) | Portoghese (europeo) | `PT-PT` | `target` |
| Rumeno | Romanian | `RO` | `source`, `target` |
| Russo | Russian | `RU` | `source`, `target` |
| Slovacco | Slovak | `SK` | `source`, `target` |
| Sloveno | Slovenian | `SL` | `source`, `target` |
| Svedese | Swedish | `SV` | `source`, `target` |
| 土耳其语 | Turkish | `TR` | `source`, `target` |
| Ucraino | Ukrainian | `UK` | `source`, `target` |
| Italiano | Chinese | `ZH` | `source`, `target` |
| 中文（简体） | Chinese (Simplified) | `ZH-HANS` | `target` |
| Cinese tradizionale | Chinese (Traditional) | `ZH-HANT` | `target` |

<div align="right"> 
<h6><small>Parte del contenuto di questa pagina è stata tradotta da GPT e potrebbe contenere errori.</small></h6>